<?php
/*
Plugin Name: MDW Maintenance
Plugin URI: http://mozartsduweb.com
Description: Mise en place d'&eacute;l&eacute;ments pour assurer la maintenance des sites Wordpress de nos clients
Version: 0.2.2
Author: Christopher ESPARGELIERE
Author URI: http://mozartsduweb.com
License: GPLv2
*/
define('MDWMAINTENANCE_VERSION','0.2.2');
define('MDWMAINTENANCE_NOM','mdw_maintenance');

define('MDWMAINTENANCE_URL_MDW','http://mdwm.mozartsduweb.com/');
define('MDWMAINTENANCE_URL_MP',	'http://maintenance.marquepages.org/');

define('PRIORITE_GRANDE','999999');

if ( ! defined('ABSPATH') ) {
	die('Please do not load this file directly.');
}







class mdwMaintenance
{
	/**
     * Holds the values to be used in the fields callbacks
     */
    private $options;
	
	/**
		* Liste des utilisateurs autoris&eacute;s
     */
    private $tab_utilisateurs = array(	"cesparge@mozartsduweb.com",
										"tb@marquepages.org");

	/**
     * Sauvegarde du menu de Wordpress avant modification de notre plugin
     */
    private $save_global_menu;
	
	/**
     * Sauvegarde du menu de Wordpress avant modification de notre plugin
     */
    private $menu_par_defaut = array (	"index.php",
										"edit.php",
										"upload.php",
										"edit-tags.php?taxonomy=link_category",
										"edit.php?post_type=page",
										"edit.php?post_type=page",
										"edit-comments.php",
										"users.php");



	/**
     * Start up
     */
    public function __construct()
    {
		register_activation_hook( 	__FILE__,	array( $this, 'mdw_activation'));
		register_deactivation_hook( __FILE__,	array( $this, 'mdw_deactivation' ));
		register_uninstall_hook( 	__FILE__,	array( $this, 'mdw_uninstall' ));
		
		wp_register_style( 'mdwm-css', plugins_url('style.css', __FILE__) );
		wp_enqueue_style( 'mdwm-css' );
		
		//add_action('admin_init', array( $this, 'mdw_verify_version' ) );	/* Verification de la version */
		add_action('admin_init', array( $this, 'mdw_control' ) );	/* Controle activation plugin */
		add_action('init', array( $this, 'mdw_end' ) ); /* Fin de maintenance */

        add_action( 'admin_menu', array( $this, 'mdwAjouterPagePlugin' ) );		// Lien dans le menu
        add_action( 'admin_init', array( $this, 'mdwPageInit' ) );				// Page enregistrement des options
		add_action( 'wp_before_admin_bar_render', array( $this, 'mdwm_scan_nodes' ), PRIORITE_GRANDE );
		
		/* Nettoyage du menu pour les admins sous maintenance */
		/* Chiffre Prio tres grand pour etre la tte derniere fonction */
		add_action(	'admin_menu', array( $this, 'mdwm_remove_menu_items'), PRIORITE_GRANDE );
		add_action( 'wp_before_admin_bar_render', array( $this, 'mdwm_remove_adminbar_nodes' ), PRIORITE_GRANDE );
		
		add_action( 'admin_notices', array( $this, 'mdwAdminNotice' ) );	/* Verif DLC de la maintenance */
		
		/* Suppr des infos de Wordpress */
		add_action(	'admin_init', array( $this, 'mdwm_suppr_info_maj' ) );
		add_filter(	'admin_footer_text', array( $this, 'mdwm_changer_footer_admin') );
    }
	
	public function mdw_activation() {

		add_option( 'mdw_maintenance',  array(
					"checkbox_stop_maintenance" => false 
		));
		add_option( 'mdwm_options',  array(
					"radio_societe_maintenance" => "MDW",
					"date_limite_maintenance" => date("Y-m-d", mktime(0, 0, 0, date("m")+3, date("d"), date("Y"))),	//3 mois de maintenance
					"radio_active_custom_login" => "non",
					"radio_desactive_maj" => "oui",
					"checkbox_menu" => $this->menu_par_defaut,
					"checkbox_adminbar" => array()
		));
	}
	
	public function mdw_deactivation() {

		update_option( 'mdw_maintenance',  array(
						"checkbox_stop_maintenance" => false, 
						"activate_need_control" 	=> true,
		));
	}

	public function mdw_uninstall() {
		delete_option( 'mdwm_options' );
		delete_option( 'mdw_maintenance' );
	}
	
	public function mdw_verify_version() {
		/* add_action comment */
		$version_distante = file_get_contents( "http://mdwm.mozartsduweb.com/plugin/version.php" );
		$diff = version_compare( MDWMAINTENANCE_VERSION, $version_distante );
		
		/*
		if( $diff == -1 )	echo "Une version plus rcente existe";
		if( $diff == 0 )	echo "Version  jour";
		*/
		
		return $diff;
	}
	
	public function mdw_control() {
		global $current_user;
		$get_option_mdw_maintenance = get_option( 'mdw_maintenance' );

		if( $get_option_mdw_maintenance != false 
			&& $get_option_mdw_maintenance['activate_need_control'] == true
			&& !in_array($current_user->user_email,$this->tab_utilisateurs) 
			) {
				wp_die( 'La r&eacute;activation de la maintenance n&eacute;cessite l\'intervention de nos techniciens.<br />
						<br />
						Merci de prendre contact avec eux',
						'Maintenance Wordpress');
		}
		elseif( $get_option_mdw_maintenance != false 
				&& $get_option_mdw_maintenance['activate_need_control'] == true
				&& in_array($current_user->user_email,$this->tab_utilisateurs) 
				) {
					/* Tant que nous ne sommes pas co une fois  l'admin, l'admin est inconsultable */
					update_option( 'mdw_maintenance',  array(
									"checkbox_stop_maintenance" => false, 
					));
		}
	}
	
	public function mdw_end() {
		$get_option_mdw_maintenance = get_option( 'mdw_maintenance' );
		if( isset( $get_option_mdw_maintenance['checkbox_stop_maintenance'] ) 
				&& $get_option_mdw_maintenance['checkbox_stop_maintenance'] == true
				&& !strchr($_SERVER['REQUEST_URI'],"plugins") 
				) {

				$current_user = wp_get_current_user();
				$mdwm_options = get_option("mdwm_options");
				
				$message = 
"Le site ".get_bloginfo('name')." vient de mettre fin a sa maintenance \n
URL				: ".get_bloginfo('url')." \n
Version			: ".get_bloginfo('version')." \n
Template URL	: ".get_bloginfo('template_url')." \n
\n
La personne ayant mis fin a la maintenance est : \n
LOGIN	:".$current_user->user_login." \n
EMAIL	:".$current_user->user_email." \n
ID		:".$current_user->ID." \n
";
				
				if ( "MDW" == $mdwm_options['radio_societe_maintenance'] ) {
					wp_mail( "support@mozartsduweb.com", "Fin de maintenance", $message ); 
				}
				elseif ( "MP" == $mdwm_options['radio_societe_maintenance'] ) {
					wp_mail( "support@marquepages.org", "Fin de maintenance", $message ); 
				}
				elseif ( "CW" == $mdwm_options['radio_societe_maintenance'] ) {
					wp_mail( "support@marquepages.org", "Fin de maintenance", $message ); 
				}

				deactivate_plugins ( plugin_dir_path( __FILE__ ).MDWMAINTENANCE_NOM.".php" );
				wp_redirect( self_admin_url("plugins.php?deactivate=true&plugin_status=$status&paged=$page&s=$s") );

				/* Suppression impossible  mettre en place - abandon */
				//delete_plugins(		 MDWMAINTENANCE_NOM."/".MDWMAINTENANCE_NOM.".php" );
				//wp_redirect( self_admin_url("plugins.php?deleted=true") );

				exit;
		}
	}

	/**
     * Add options page
     */
    public function mdwAjouterPagePlugin()
    {
		global $submenu;
		$mdwm_options = get_option("mdwm_options");

		if ( "MDW" == $mdwm_options['radio_societe_maintenance'] ) {
			add_menu_page(	'MDW Maintenance', 'MDW Mainten.', 'manage_options', 'mdw-maintenance',
							array( $this,'mdwmPageGeneral'), plugin_dir_url( __FILE__ )."/img/mdw/logo-16.png" , 3 );
		}
		elseif ( "MP" == $mdwm_options['radio_societe_maintenance'] ) {
			add_menu_page(	'MP Maintenance', 'MP Mainten.', 'manage_options', 'mdw-maintenance',
							array( $this,'mdwmPageGeneral'), plugin_dir_url( __FILE__ )."/img/mp/logo-16.png" , 3 );
		}
		elseif ( "CW" == $mdwm_options['radio_societe_maintenance'] ) {
			add_menu_page(	'CW Maintenance', 'CW Mainten.', 'manage_options', 'mdw-maintenance',
							array( $this,'mdwmPageGeneral'), plugin_dir_url( __FILE__ )."/img/cw/logo-16.png" , 3 );
		}

			add_submenu_page( 	'mdw-maintenance',
								'Options', 'Options', 'manage_options', 'mdwm-options',
								array( $this,'mdwmPageOptions') );

		/* On modifie le nom du premier &eacute;l&eacute;ment */
		$submenu['mdw-maintenance'][0][0] = 'G&eacute;n&eacute;ral';
    }
	
	
	
	/**
     * Construction de la page generale du plugin
     */
    public function mdwmPageGeneral()
    {
		$current_user = wp_get_current_user();
		if (!current_user_can('administrator'))  {
			wp_die( __('You do not have sufficient permissions to access this page.') );
		}
		
		$mdwm_options = get_option("mdwm_options");

		if ( !in_array($current_user->user_email,$this->tab_utilisateurs) )  {
?>
			<div class="wrap admin-mdw-maintenance">
			<?php if ( "MDW" == $mdwm_options['radio_societe_maintenance'] ) { ?>
				<div id="icone-logo-32">
					<img src="<?php echo plugins_url( '/img/mdw/logo-64.png' , __FILE__ ); ?>" alt="" />
				</div>
				<h2>MDW_Maintenance</h2>
			<?php } elseif ( "MP" == $mdwm_options['radio_societe_maintenance'] ) { ?>
				<div id="icone-logo-32">
					<img src="<?php echo plugins_url( '/img/mp/logo-64.png' , __FILE__ ); ?>" alt="" />
				</div>
				<h2>MP_Maintenance</h2>
			<?php } elseif ( "CW" == $mdwm_options['radio_societe_maintenance'] ) { ?>
				<div id="icone-logo-32">
					<img src="<?php echo plugins_url( '/img/cw/logo-64.png' , __FILE__ ); ?>" alt="" />
				</div>
				<h2>CW_Maintenance</h2>
			<?php } ?>
				<div class="inner_wrap">
					<div class="sidebar-callout">
						<?php 
						if ( "MDW" == $mdwm_options['radio_societe_maintenance'] )
							echo $this->consulter_fichier_distant( MDWMAINTENANCE_URL_MDW."callout.php" );
						elseif ( "MP" == $mdwm_options['radio_societe_maintenance'] )
							echo $this->consulter_fichier_distant( MDWMAINTENANCE_URL_MP."callout.php" );
						elseif ( "CW" == $mdwm_options['radio_societe_maintenance'] )
							echo $this->consulter_fichier_distant( MDWMAINTENANCE_URL_MDW."callout.php" );
						?>
					</div>
					<h3>Module de maintenance</h3>
					<p>Notre soci&eacute;t&eacute; a mis au point cette extension dans le but de s&eacute;curiser vos interactions avec votre site internet.</p>
					<p>Vous avez ainsi acc&egrave;s &agrave; votre site internet en tant qu'administrateur et disposez de tous les privil&egrave;ges. Toutefois, nous vous avons cach&eacute; certains &eacute;l&eacute;ments du menu qui sont pour vous inutiles et generait votre experience.</p>
					<br />
					<br />
					<h3>D&eacute;sactivation de la maintenance</h3>
					<p>Comme vous pouvez le voir ci-dessous, nous vous avons laiss&eacute; la possibilit&eacute; de reprendre la main sur votre site en d&eacute;sactivant notre extension.</p>
					<h3>Appuyez sur ce bouton revient &agrave; annuler la garantie li&eacute; &agrave; votre maintenance.</h3>
					<p>Un seul bouton &agrave; presser et vous reprenez totalement le controle.</p>
					<br />
					<br />
					<form id="fin-maintenance" method="POST" action="options.php">
						<?php
							// This prints out all hidden setting fields
							settings_fields( 'mdw_maintenance_general' );   
							do_settings_sections( 'mdw-maintenance-page' );
							submit_button('Mettre fin &agrave; la maintenance','button-large button-primary'); 
						?>
					</form>
				</div>
			</div>
		<?php
		}
		else {
		?>
			<div class="wrap admin-mdw-maintenance">
			<?php if ( "MDW" == $mdwm_options['radio_societe_maintenance'] ) { ?>
				<div id="icone-logo-32">
					<img src="<?php echo plugins_url( '/img/mdw/logo-64.png' , __FILE__ ); ?>" alt="" />
				</div>
				<h2>MDW_Maintenance</h2>
			<?php } elseif ( "MP" == $mdwm_options['radio_societe_maintenance'] ) { ?>
				<div id="icone-logo-32">
					<img src="<?php echo plugins_url( '/img/mp/logo-64.png' , __FILE__ ); ?>" alt="" />
				</div>
				<h2>MP_Maintenance</h2>
			<?php } elseif ( "CW" == $mdwm_options['radio_societe_maintenance'] ) { ?>
				<div id="icone-logo-32">
					<img src="<?php echo plugins_url( '/img/cw/logo-64.png' , __FILE__ ); ?>" alt="" />
				</div>
				<h2>CW_Maintenance</h2>
			<?php } ?>
				<div class="updated"><p>Note : <em>Cette page n'est visible qu'aux utilisateurs <strong>autoris&eacute;s</strong></em>.</p></div>
				<?php /* if( 0 > $this->mdw_verify_version() ) {	?>
					<div id="message" class="error"><p>Une mise &agrave; jour est disponible : <em>http://mdwm.mozartsduweb.com/plugin</em></p></div>
				<?php }	*/ ?>
				<div class="inner_wrap">
					<div class="sidebar-callout">
						<?php 
						if ( "MDW" == $mdwm_options['radio_societe_maintenance'] )
							echo $this->consulter_fichier_distant( MDWMAINTENANCE_URL_MDW."callout.php" );
						elseif ( "MP" == $mdwm_options['radio_societe_maintenance'] )
							echo $this->consulter_fichier_distant( MDWMAINTENANCE_URL_MP."callout.php" );
						elseif ( "CW" == $mdwm_options['radio_societe_maintenance'] )
							echo $this->consulter_fichier_distant( MDWMAINTENANCE_URL_MDW."callout.php" );
						?>
					</div>
					<h3>Notice</h3>
					<p>
						<strong>G&eacute;n&eacute;ral</strong> : Notice du site pour les Administrateurs autoris&eacute;s (CHRIS et TB) <br />
						Les Administrateurs classiques ont la possibilit&eacute; de d&eacute;sactiver la maintenance &agrave; jamais sur cette page via un second jeu d'options.
					</p>
					<p><em>L'ensemble des options suivantes ne sont accessibles <strong>Administrateurs autoris&eacute;s</strong></em></p>
					<p><strong>Options</strong> : Elements divers comprenant le choix de la soci&eacute;t&eacute;, la s&eacute;curisation du site et des techniques de sauvegarde</p>
					<br />
					<h3>Aide m&eacute;moire</h3>
					<p>En cas de d&eacute;sactivation de la maintenance par un client puis r&eacute;activation, son administration sera <b>bloqu&eacute;</b> dans l'attente de l'intervention d'un technicien. De notre cot&eacute;, le simple fait de se connecter &agrave; l'administration avec nos comptes SuperAdmin leur d&eacute;bloquera la situation (syst&egrave;me auto).</p>
					<br />
					<h3>Changelog :</h3>
					<p><strong>0.2.1</strong> : Ajout des icones des soci&eacute;t&eacute;s. Ouverture du plugin sur le front &agrave; cause de l'adminbar</p>
					<p><strong>0.2</strong> : Simplification du fonctionnement, une page unique d'options</p>
					<p><strong>0.1</strong> : Premiere version du module, necessite des corrections</p>
				</div>
			</div>
		<?php
		}
    }
	
	/**
     * Construction de la page des options
     */
    public function mdwmPageOptions()
    {
		// Set class property
        $this->options = get_option( 'mdwm_options' );
	?>
		<div class="wrap admin-mdw-maintenance">
			<?php if( isset($_GET['settings-updated']) ) { ?>
				<div id="message" class="updated">
					<p><strong><?php _e('Settings saved.') ?></strong></p>
				</div>
			<?php } ?>
			
			<?php if ( "MDW" == $this->options['radio_societe_maintenance'] ) { ?>
				<div id="icone-logo-32">
					<img src="<?php echo plugins_url( '/img/mdw/logo-64.png' , __FILE__ ); ?>" alt="" />
				</div>
				<h2>MDW_Maintenance : Options</h2>
			<?php } elseif ( "MP" == $this->options['radio_societe_maintenance'] ) { ?>
				<div id="icone-logo-32">
					<img src="<?php echo plugins_url( '/img/mp/logo-64.png' , __FILE__ ); ?>" alt="" />
				</div>
				<h2>MP_Maintenance : Options</h2>
			<?php } elseif ( "CW" == $this->options['radio_societe_maintenance'] ) { ?>
				<div id="icone-logo-32">
					<img src="<?php echo plugins_url( '/img/cw/logo-64.png' , __FILE__ ); ?>" alt="" />
				</div>
				<h2>CW_Maintenance : Options</h2>
			<?php } ?>

			<form method="POST" action="options.php">
				<?php
					// This prints out all hidden setting fields
					settings_fields( 'mdw_maintenance_options' );   
					do_settings_sections( 'mdwm-options' );
					submit_button(); 
				?>
			</form>
		</div> <!-- Fin du wrap -->
	
	<?php
	}
	
	
	
	
	
	/**
     * Register and add settings
     */
    public function mdwPageInit()
    {        
		register_setting(
            'mdw_maintenance_general', // Option group
            'mdw_maintenance' // Option name
        );
		add_settings_section(
			'section_general', // ID
			'', // Title
			'', // Callback
			'mdw-maintenance-page' // Page
		);
		add_settings_field(
			'checkbox_stop_maintenance', // ID
			'', // Title
			array( $this, 'print_checkbox_stop_maintenance' ), // Callback
			'mdw-maintenance-page', // Page
			'section_general' // Section   
		);

		/*#############*/

		register_setting(
            'mdw_maintenance_options', // Option group
            'mdwm_options', // Option name
            array( $this, 'sanitize' ) // Sanitize
        );

		add_settings_section(
			'section_societe', // ID
			'Soci&eacute;t&eacute; pour la maintenance', // Title
			'', // Callback
			'mdwm-options' // Page
		);
		add_settings_field(
			'radio_societe_maintenance', // ID
			'Quelle soci&eacute;t&eacute; s\'occupe de la maintenance ?', // Title
			array( $this, 'print_radio_societe_maintenance' ), // Callback
			'mdwm-options', // Page
			'section_societe' // Section   
		);
		add_settings_field(
			'date_limite_maintenance', // ID
			'Date limite de validit&eacute;<br />
			<span style="font-size:9px;font-style:italic;">Forme de date : AAAA-MM-JJ</span>', // Title
			array( $this, 'print_date_limite_maintenance' ), // Callback
			'mdwm-options', // Page
			'section_societe' // Section   
		);
		
		add_settings_section(
			'section_desact_maj', // ID
			'Mise &agrave; jour', // Title
			'', // Callback
			'mdwm-options' // Page
		);
		add_settings_field(
			'radio_desactive_maj', // ID
			'Voulez-vous d&eacute;sactiver les alertes de mise &agrave; jour ?', // Title
			array( $this, 'print_radio_desactive_maj' ), // Callback
			'mdwm-options', // Page
			'section_desact_maj' // Section   
		);
		
		add_settings_section(
			'section_custom_login', // ID
			'Custom du login', // Title
			'', // Callback
			'mdwm-options' // Page
		);
		add_settings_field(
			'radio_active_custom_login', // ID
			'Voulez-vous activer la customisation de wp-login ?<br />
			<span style="font-size:9px;font-style:italic;">/wp-content/plugins/mdw_maintenance/plugins/custom-admin-login/css/style.css</span>', // Title
			array( $this, 'print_radio_active_custom_login' ), // Callback
			'mdwm-options', // Page
			'section_custom_login' // Section   
		);

		add_settings_section(
			'section_menu', // ID
			'Afficher/Cacher le menu', // Title
			'', // Callback
			'mdwm-options' // Page
		); 
		add_settings_field(
			'checkbox_menu', // ID
			'S&eacute;lection des pages visibles aux yeux de tous<br /><br />
			<strong>Coch&eacute;</strong> = Visible de tous<br /><br />
			<strong>D&eacute;coch&eacute;</strong> = Visible que par les super-admins', // Title
			array( $this, 'print_checkbox_menu' ), // Callback
			'mdwm-options', // Page
			'section_menu' // Section   
		);
		add_settings_field(
			'checkbox_adminbar', // ID
			'S&eacute;lection des noeuds de l\'Admin Barre visibles aux yeux de tous<br /><br />
			<strong>Coch&eacute;</strong> = Visible de tous<br /><br />
			<strong>D&eacute;coch&eacute;</strong> = Visible que par les super-admins', // Title
			array( $this, 'print_checkbox_adminbar' ), // Callback
			'mdwm-options', // Page
			'section_menu' // Section   
		); 


		
    }
	
	/**
     * Sanitize each setting field as needed
     *
     * @param array $input Contains all settings fields as array keys
     */
    public function sanitize( $input )
    {
		/*
        $new_input = array();
        if( isset( $input['id_number'] ) )
            $new_input['id_number'] = absint( $input['id_number'] );

        if( isset( $input['title'] ) )
            $new_input['title'] = sanitize_text_field( $input['title'] );
		*/


		/* OPTIONS */
		/* Soci&eacute;t&eacute; qui s'occupe de la maintenance */
		if( isset( $input['radio_societe_maintenance'] ) )
            $new_input['radio_societe_maintenance'] = $input['radio_societe_maintenance'];

		/* Quelle est la date limite pour cette maintenance ? */
		if( isset( $input['date_limite_maintenance'] ) )
            $new_input['date_limite_maintenance'] = $input['date_limite_maintenance'];
		
		/* Est ce que l'on affiche les alertes mises a jour aux clients */
		if( isset( $input['radio_desactive_maj'] ) )
            $new_input['radio_desactive_maj'] = $input['radio_desactive_maj'];
		
		/* Est ce que custom de l'admin */
		if( isset( $input['radio_active_custom_login'] ) )
            $new_input['radio_active_custom_login'] = $input['radio_active_custom_login'];
			
		/* Choix des elements du menu visible de tous et des admins */
		if( isset( $input['checkbox_menu'] ) )
			$new_input['checkbox_menu'] = $input['checkbox_menu'];

		/* Choix des elements de la wp_admin_barre noire en haut visible de tous et des admins */
		/* Logique inverse, on ne veut stocker en BDD que les d&eacute;coch&eacute;s */
		if( isset( $input['checkbox_adminbar'] ) ) {
			
			$listing_noeuds = array();
			$liste = glob( plugin_dir_path( __FILE__ )."admin/node/*.txt" );
			foreach ($liste as $nom_fichier) {
				$test = file_get_contents($nom_fichier);
				$node_explode = explode( ";", $test);
				$listing_noeuds[] = $node_explode[0];
			}
		
			$new_input['checkbox_adminbar'] = array_diff($listing_noeuds, $input['checkbox_adminbar']);
		}

        return $new_input;
    }

	
	
	/** 
	 * GENERAL : Voulez-vous stopper la maintenance ?
     */
    public function print_checkbox_stop_maintenance()
    {
		$get_option_mdw_maintenance = get_option( 'mdw_maintenance' );
		printf(
            '<input type="checkbox" id="checkbox_stop_maintenance" name="mdw_maintenance[checkbox_stop_maintenance]" %s /> En cochant cette case, je reconnais perdre mes privil&egrave;ges de maintenance.',
			isset( $get_option_mdw_maintenance['checkbox_stop_maintenance'] ) && $get_option_mdw_maintenance['checkbox_stop_maintenance'] == true ? 'checked' : ''
        );
	}
	
	
	
	/** 
	 * OPTIONS : Qui gere la maintenance
     */
    public function print_radio_societe_maintenance()
    {
		printf(
            '<input type="radio" id="radio_societe_maintenance_MDW" name="mdwm_options[radio_societe_maintenance]" value="MDW" %s /> MozArtsduWeb (logo &agrave; pr&eacute;voir) <br />',
            isset( $this->options['radio_societe_maintenance'] ) && $this->options['radio_societe_maintenance'] == "MDW" ? 'checked' : ''
        );
		printf(
            '<input type="radio" id="radio_societe_maintenance_MP" name="mdwm_options[radio_societe_maintenance]" value="MP" %s /> marquePages (logo &agrave; pr&eacute;voir) <br />',
			isset( $this->options['radio_societe_maintenance'] ) && $this->options['radio_societe_maintenance'] == "MP" ? 'checked' : ''
        );
		printf(
            '<input type="radio" id="radio_societe_maintenance_CW" name="mdwm_options[radio_societe_maintenance]" value="CW" %s /> Le Comptoir du Web <br />',
			isset( $this->options['radio_societe_maintenance'] ) && $this->options['radio_societe_maintenance'] == "CW" ? 'checked' : ''
        );
    }
	
	/** 
	 * OPTIONS : Quelle est la date limite pour cette maintenance ?
     */
    public function print_date_limite_maintenance()
    {
		printf(
            '<input type="text" id="date_limite_maintenance" name="mdwm_options[date_limite_maintenance]" value="%s" />',
            isset( $this->options['date_limite_maintenance'] ) ? $this->options['date_limite_maintenance'] : ''
        );
    }
	
	/** 
	 * OPTIONS : Est ce que l'on affiche les alertes mises a jour aux clients
     */
    public function print_radio_desactive_maj()
    {
		printf(
            '<input type="radio" id="radio_desactive_maj_OUI" name="mdwm_options[radio_desactive_maj]" value="oui" %s /> Oui <br />',
            isset( $this->options['radio_desactive_maj'] ) && $this->options['radio_desactive_maj'] == "oui" ? 'checked' : ''
        );
		printf(
            '<input type="radio" id="radio_desactive_maj_NON" name="mdwm_options[radio_desactive_maj]" value="non" %s /> Non <br />',
			isset( $this->options['radio_desactive_maj'] ) && $this->options['radio_desactive_maj'] == "non" ? 'checked' : ''
        );
	}

	/** 
	 * OPTIONS : Est ce que custom de l'admin ?
     */
    public function print_radio_active_custom_login()
    {
		printf(
            '<input type="radio" id="radio_active_custom_login_OUI" name="mdwm_options[radio_active_custom_login]" value="oui" %s /> Oui <br />',
            isset( $this->options['radio_active_custom_login'] ) && $this->options['radio_active_custom_login'] == "oui" ? 'checked' : ''
        );
		printf(
            '<input type="radio" id="radio_active_custom_login_NON" name="mdwm_options[radio_active_custom_login]" value="non" %s /> Non <br />',
			isset( $this->options['radio_active_custom_login'] ) && $this->options['radio_active_custom_login'] == "non" ? 'checked' : ''
        );
    }
	
	/** 
	 * OPTIONS : Affiche les elements du menu et on coche ceux que tout le monde peut voir
     */
    public function print_checkbox_menu()
    {
		print '<table class="form-table table-serre">';
		foreach ($this->save_global_menu as $menu_element ) {
			if( strchr($menu_element[2],"separator")) {
				print( '<tr valign="top"><td>&nbsp;</td><td>-----</td></tr>' );
			}
			elseif( strchr($menu_element[2],"mdw-maintenance")) {
				/* On ne va pas afficher notre bouton de maintenance dans cette liste */
			}
			else {
				printf(
					'<tr valign="top">
					<td class="col_check"><input type="checkbox" id="checkbox_menu" name="mdwm_options[checkbox_menu][]" value="%s" %s /></td>
					<td>%s</td></tr>',
					$menu_element[2],//slug
					in_array( $menu_element[2],$this->options['checkbox_menu'] ) ? 'checked' : '',
					$menu_element[0]
				);
			}
		}
		print '</table>';
	}
	
	/** 
	 * OPTIONS : Affiche les noeuds de la barre d'administration et on coche ceux que tout le monde peut voir
     */
    public function print_checkbox_adminbar()
    {
		/* 	global $wp_admin_bar;
			$all_toolbar_nodes = $wp_admin_bar->get_nodes();
			A l'appel de cette page, wp_admin_bar est vide, 
			une autre fonction se charge de lister tous les noeuds
			pour les sauvegarder sous fichier texte dans admin/node
			*/

		$listing_noeuds = array();
		$liste = glob( plugin_dir_path( __FILE__ )."admin/node/*.txt" );
		foreach ($liste as $nom_fichier) {
			$test = file_get_contents($nom_fichier);
			$node_explode = explode( ";", $test);
			$listing_noeuds[] = array('id'=>$node_explode[0], 'title'=>$node_explode[1]);
		}
		
		// $listing_noeuds represente tous les noeuds qui sont sauvegard&eacute;s dans les fichiers de reference (ils existent)
		// En BDD, on a stock&eacute; les noeuds que l'on ne veut pas voir (les d&eacute;coch&eacute;s)

		print '<table class="form-table table-serre">';
		foreach ($listing_noeuds as $key => $node ) {
			printf(
				'<tr valign="top">
				<td class="col_check"><input type="checkbox" id="checkbox_adminbar" name="mdwm_options[checkbox_adminbar][]" value="%s" %s /></td>
				<td>%s</td></tr>',
				$node['id'],//slug
				!in_array( $node['id'],$this->options['checkbox_adminbar'] ) ? 'checked' : '',
				$node['id']
			);
		}
		print '</table>';
	}



	//Inspir&eacute; de - https://codex.wordpress.org/Function_Reference/get_nodes
	// use 'wp_before_admin_bar_render' hook to also get nodes produced by plugins.
	public function mdwm_scan_nodes() {
		global $wp_admin_bar;
		$all_toolbar_nodes = $wp_admin_bar->get_nodes();

		if ( $all_toolbar_nodes ) {
			foreach ( $all_toolbar_nodes as $node  ) {
				$args = array(
					'id'     => $node->id,
					'title'  => $node->title,
					//'href' 	 => $node->href
				);
				file_put_contents( 
					plugin_dir_path( __FILE__ )."admin/node/".$node->id.".txt",
					implode(';',$args)
					);
			}
		}
	}

	
	public function mdwm_remove_menu_items() {
		global $menu, $submenu;
		global $current_user;
		
		$mdwm_options = get_option("mdwm_options");

		$this->save_global_menu = $menu; 	//Duplique pour garder les valeurs du menu d'origine (avant modification)
		ksort( $this->save_global_menu );	//Le menu n'est pas rang&eacute; selon les positions
		
		foreach( $menu as $key => $menu_element ) {
			if( strchr($menu_element[2],"separator")) { 
				/* On saute ce cas */
			}
			elseif( strchr($menu_element[2],"mdw-maintenance")) {
				/* On va cacher le bouton "Mdw Maintenance > Options" auprs des non SuperAdmin */
				if ( !in_array($current_user->user_email,$this->tab_utilisateurs) )  {
					remove_submenu_page( "mdw-maintenance", "mdwm-options" );
				}
			}
			else {
				if(!in_array($menu_element[2], $mdwm_options['checkbox_menu'])){
					if ( in_array($current_user->user_email,$this->tab_utilisateurs) )  {
						$menu[$key][0] = "* ".$menu[$key][0];
					}
					else {
						unset($menu[$key]);
					}
				}
			}
		}
	}
	
	
	public function mdwm_remove_adminbar_nodes() {
		global $wp_admin_bar;
		global $current_user;
		
		$mdwm_options = get_option("mdwm_options");
		$all_toolbar_nodes = $wp_admin_bar->get_nodes();
		
		foreach( $all_toolbar_nodes as $node ) {
			if( in_array($node->id, $mdwm_options['checkbox_adminbar']) ) {
				if ( in_array($current_user->user_email,$this->tab_utilisateurs) )  {
					$node->title = "* ".$node->title;
					$wp_admin_bar->add_node( $node );
				}
				else {
					$wp_admin_bar->remove_node( $node->id );
				}
			}
		}
	}
	
	
	public function mdwAdminNotice() { 
		$mdwm_options = get_option("mdwm_options");
		
		$dateExpiration = strtotime($mdwm_options['date_limite_maintenance']);
		$dateDuJour = time();
		
		if( $dateDuJour > $dateExpiration ) {
			echo "<div class='error'>";
			if ( "MDW" == $mdwm_options['radio_societe_maintenance'] )
				echo "<p>Votre maintenance est arriv&eacute; &agrave; expiration. Merci de prendre contact avec la soci&eacute;t&eacute; <a href='http://mozartsduweb.com'>MozArtsduWeb</a>";
			elseif ( "MP" == $mdwm_options['radio_societe_maintenance'] )
				echo "<p>Votre maintenance est arriv&eacute; &agrave; expiration. Merci de prendre contact avec la soci&eacute;t&eacute; <a href='http://marquepages.org'>marquePages</a>";
			elseif ( "CW" == $mdwm_options['radio_societe_maintenance'] )
				echo "<p>Votre maintenance est arriv&eacute; &agrave; expiration. Merci de prendre contact avec la soci&eacute;t&eacute; le comptoir du Web";
			echo "</div>";
		}
	}
	
	
	public function mdwm_suppr_info_maj() {
		global $current_user;
		global $menu,$submenu;
		
		$mdwm_options = get_option("mdwm_options");

		if ( "oui" == $mdwm_options['radio_desactive_maj'] && !in_array($current_user->user_email,$this->tab_utilisateurs) ) {
			/* Pour WP 2.8  3.0 */
			remove_action( 'wp_version_check', 'wp_version_check' );  
			remove_action( 'admin_init', '_maybe_update_core' );

			/* supprimer les notifications du core */
			add_filter( 'pre_site_transient_update_core', create_function( '$a', "return null;" ) );
			
			/* supprimer les notifications de thmes */
			remove_action( 'load-update-core.php', 'wp_update_themes' );
			add_filter( 'pre_site_transient_update_themes', create_function( '$a', "return null;" ) );
			
			/* supprimer les notifications de plugins */
			remove_action( 'load-update-core.php', 'wp_update_plugins' );
			add_filter( 'pre_site_transient_update_plugins', create_function( '$a', "return null;" ) );

			/* On va cacher dans le menu */
			unset($submenu['index.php'][10]);	/*MAJ in dashboard*/
			
			if( array_key_exists(65,$menu) )
				$menu[65][0] = __('Plugins');
		}
	}
	
	
	public function mdwm_changer_footer_admin () {
	
		$mdwm_options = get_option("mdwm_options");

		if ( "MDW" == $mdwm_options['radio_societe_maintenance'] )
			echo "Merci d'avoir choisi <a href='http://mozartsduweb.com'>MozArtsduWeb</a> pour votre maintenance";
		elseif ( "MP" == $mdwm_options['radio_societe_maintenance'] )
			echo "Merci d'avoir choisi <a href='http://marquepages.org'>marquePages</a> pour votre maintenance";
		elseif ( "CW" == $mdwm_options['radio_societe_maintenance'] )
			echo "Merci d'avoir choisi le comptoir du Web pour votre maintenance";
	}
	
	
	
	/* FONCTION BOITE A OUTILS */
	public function consulter_fichier_distant($url) {
		$ch = curl_init();
		$timeout = 5;
		curl_setopt ($ch, CURLOPT_URL, $url);
		curl_setopt ($ch, CURLOPT_RETURNTRANSFER, 1);
		curl_setopt ($ch, CURLOPT_CONNECTTIMEOUT, $timeout);
		$file_contents = curl_exec($ch);
		curl_close($ch);
		return $file_contents;
	}
	
}

/* Mise en place du custom logo */
include('plugins/custom-admin-login/custom-admin-login.php');

/* La barre noire doit aussi tre cach quand nous sommes sur le front
if( is_admin() )
*/
    $ma_mdwMaintenance = new mdwMaintenance();



?>